@@ -83,7 +83,7 @@ class Query
         $this->sort  = array('field' => 'Date', 'ascending' => 'false');
         $this->type = $type;
 
-        $this->spamQuery = $App->getConfig('SPAM_QUERY','AND NOT HEADER-X-SPAM-FLAG:YES');
+        $this->spamQuery = $App->getConfig('SPAM_QUERY','NOT HEADER-X-SPAM-FLAG:YES');
     }
 
 
