@@ -45,5 +45,10 @@ switch ($App->lang) {
 }
 $App->assign('LOCALE',$LOCALE);
 
-
+if ($customize_dir = $App->getConfig('THEME_DIR')) {
+    $custom_txt_file = $customize_dir.'/'.$App->lang.'.txt';
+    if (is_readable($custom_txt_file)) {
+        $App->assign('THEME_TXT_FILE',$custom_txt_file);
+    }
+}
 ?>
